Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(340)

Unified Diff: remoting/host/daemon_process_win.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/curtain_mode_mac.cc ('k') | remoting/host/desktop_environment.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/daemon_process_win.cc
diff --git a/remoting/host/daemon_process_win.cc b/remoting/host/daemon_process_win.cc
index b360d88d0247c994e1d7173dc067c989947b75d4..85706d59e31ee213e1c49d64f8f5ffb1de4f75bc 100644
--- a/remoting/host/daemon_process_win.cc
+++ b/remoting/host/daemon_process_win.cc
@@ -237,7 +237,7 @@ scoped_ptr<DaemonProcess> DaemonProcess::Create(
void DaemonProcessWin::DisableAutoStart() {
ScopedScHandle scmanager(
- OpenSCManager(NULL, SERVICES_ACTIVE_DATABASE,
+ OpenSCManager(nullptr, SERVICES_ACTIVE_DATABASE,
SC_MANAGER_CONNECT | SC_MANAGER_ENUMERATE_SERVICE));
if (!scmanager.IsValid()) {
PLOG(INFO) << "Failed to connect to the service control manager";
@@ -253,19 +253,19 @@ void DaemonProcessWin::DisableAutoStart() {
return;
}
// Change the service start type to 'manual'. All |NULL| parameters below mean
// that there is no change to the corresponding service parameter.
if (!ChangeServiceConfig(service.Get(),
SERVICE_NO_CHANGE,
SERVICE_DEMAND_START,
SERVICE_NO_CHANGE,
- NULL,
- NULL,
- NULL,
- NULL,
- NULL,
- NULL,
- NULL)) {
+ nullptr,
+ nullptr,
+ nullptr,
+ nullptr,
+ nullptr,
+ nullptr,
+ nullptr)) {
PLOG(INFO) << "Failed to change the '" << kWindowsServiceName
<< "'service start type to 'manual'";
}
@@ -358,7 +358,7 @@ bool DaemonProcessWin::OpenPairingRegistry() {
security_attributes.lpSecurityDescriptor = sd.get();
security_attributes.bInheritHandle = FALSE;
- HKEY key = NULL;
+ HKEY key = nullptr;
result = ::RegCreateKeyEx(
root.Handle(), kPairingRegistrySecretsKeyName, 0, nullptr, 0,
KEY_READ | KEY_WRITE, &security_attributes, &key, &disposition);
@@ -253,19 +253,19 @@ void DaemonProcessWin::DisableAutoStart() {
return;
}
- // Change the service start type to 'manual'. All |NULL| parameters below mean
- // that there is no change to the corresponding service parameter.
+ // Change the service start type to 'manual'. All |nullptr| parameters below
+ // mean that there is no change to the corresponding service parameter.
if (!ChangeServiceConfig(service.Get(),
SERVICE_NO_CHANGE,
« no previous file with comments | « remoting/host/curtain_mode_mac.cc ('k') | remoting/host/desktop_environment.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698